@@ -1,10 +1,10 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer::Logger::LogReport;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use base 'Dancer::Logger::Abstract', 'Exporter';
 
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 
 use Scalar::Util            qw/blessed/;
-use Log::Report             'logreport', import => 'report';
+use Log::Report             'log-report', import => 'report';
 use Log::Report::Dispatcher ();
 
 our $AUTHORITY = 'cpan:MARKOV';
