@@ -1,10 +1,10 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
 package Dancer2::Logger::LogReport;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 # ABSTRACT: Dancer2 logger engine for Log::Report
 
@@ -14,13 +14,10 @@ use warnings;
 use Moo;
 use Dancer2::Core::Types;
 use Scalar::Util qw/blessed/;
-use Log::Report  'logreport', syntax => 'REPORT', mode => 'DEBUG';
+use Log::Report  'log-report', syntax => 'REPORT', mode => 'DEBUG';
 
 our $AUTHORITY = 'cpan:MARKOV';
 
-# all dispatchers shall be created exactly once (unique name)
-my %disp_objs;
-
 my %level_dancer2lr =
   ( core  => 'TRACE'
   , debug => 'TRACE'
@@ -47,9 +44,7 @@ sub BUILD
         {   my $type = delete $config->{type}
                 or die "dispatcher configuration $name without type";
 
-            $disp_objs{$name} = $self->app_name;
             dispatcher $type, $name, %$config;
-
         }
     }
 }
