@@ -1,4 +1,4 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@ use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use base 'Exporter';
 
@@ -55,7 +55,7 @@ require Log::Report::Dispatcher::Try;
 #, translator => Log::Report::Translator::POT->new(charset => 'utf-8');
 textdomain 'log-report';
 
-dispatcher PERL => 'default', accept => 'NOTICE-';
+my $default_dispatcher = dispatcher PERL => 'default', accept => 'NOTICE-';
 
 
 sub report($@)
@@ -174,7 +174,7 @@ sub dispatcher($@)
         }
         else
         {   my $has = first {$_->name eq $name} @$disps;
-            if(defined $has)
+            if(defined $has && $has ne $default_dispatcher)
             {   trace "not reopening $name";
                 return $has;
             }
