@@ -1,4 +1,4 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,11 +7,11 @@ use warnings;
 
 package Log::Report::DBIC::Profiler;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use base 'DBIx::Class::Storage::Statistics';
 
-use Log::Report  import => 'trace';
+use Log::Report  'log-report', import => 'trace';
 use Time::HiRes  qw(time);
 
 
