@@ -1,4 +1,4 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 
 use Log::Report 'log-report';
@@ -146,6 +146,7 @@ sub needs(;$)
     first {$need eq $_} @$needs;
 }
 
+#-----------
 
 sub log($$$$)
 {   panic "method log() must be extended per back-end";
@@ -252,12 +253,11 @@ sub collectLocation()
     my $nest  = 1;
     my @args;
 
-    do {@args = caller $nest++}
+    do { @args = caller $nest++ }
     until $args[3] eq 'Log::Report::report';  # common entry point
 
-    # skip syntax==SHORT routine entries
     @args = caller $nest++
-        if +(caller $nest)[3] =~ m/^Log\:\:Report\:\:[^:]*$/;
+        if +((caller $nest)[3] || '') =~ m/^Log\:\:Report\:\:[^:]*$/;
 
     @args ? \@args : undef;
 }
