@@ -1,4 +1,4 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,11 +7,11 @@ use strict;
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 
 use Log::Report      'log-report';
-use Log::Report::Util qw/is_fatal/;
+use Log::Report::Util qw/is_fatal to_html/;
 use POSIX             qw/locale_h/;
 use Scalar::Util      qw/blessed/;
 
@@ -67,9 +67,7 @@ sub throw(@)
     {   $reason = $self->{reason};
     }
 
-    $opts->{stack} = Log::Report::Dispatcher->collectStack
-        unless $opts->{stack} && @{$opts->{stack}};
-
+    $opts->{stack} ||= Log::Report::Dispatcher->collectStack;
     report $opts, $reason, $self;
 }
 
@@ -77,13 +75,16 @@ sub throw(@)
 sub PROPAGATE($$) {shift}
 
 
-sub toString()
-{   my $self = shift;
+sub toString(;$)
+{   my ($self, $locale) = @_;
     my $msg  = $self->message;
-    lc($self->{reason}) . ': ' . (ref $msg ? $msg->toString : $msg) . "\n";
+    lc($self->{reason}).': '.(ref $msg ? $msg->toString($locale) : $msg)."\n";
 }
 
 
+sub toHTML(;$) { to_html($_[0]->toString($_[1])) }
+
+
 sub print(;$)
 {   my $self = shift;
     (shift || *STDERR)->print($self->toString);
