@@ -1,4 +1,4 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -7,12 +7,13 @@ use strict;
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 
 use Log::Report 'log-report';
-use POSIX      qw/locale_h/;
-use List::Util qw/first/;
+use POSIX             qw/locale_h/;
+use List::Util        qw/first/;
+use Log::Report::Util qw/to_html/;
 
 # Work-around for missing LC_MESSAGES on old Perls and Windows
 { no warnings;
@@ -173,6 +174,11 @@ sub _expand($$)
 }
 
 
+my %tohtml = qw/  > gt   < lt   " quot  & amp /;
+
+sub toHTML(;$) { to_html($_[0]->toString($_[1])) }
+
+
 sub untranslated()
 {  my $self = shift;
      (defined $self->{_prepend} ? $self->{_prepend} : '')
